sampleData: Example Patient Tumor Data

Description Usage Format Source Examples

Description

Sample of control arm data for package examples from a phase 3, randomized, open-label study evaluating DN-101 in combination with Docetaxel in androgen-independent prostate cancer (AIPC) (ASCENT-2). The data was obtained from Project Data Sphere (sponsor Novacea, Inc).

Usage

1
data("sampleData")

Format

A data frame with 1250 observations on the following 3 variables.

name

a numeric vector uniquely identifying patient

date

a numeric vector for the date of measurement

size

a numeric vector for the measurement

Project Data Sphere (sponsor Novacea, Inc). https://www.projectdatasphere.org/projectdatasphere/html/content/89

Examples

1
2

wilkersj/tumgr documentation built on May 4, 2019, 5:25 a.m.